@@ -2,23 +2,44 @@
 
 # Tools for ploting the data from NetCDF file, using only numpy and matplotlib libs.
 
-# import numpy as np
 import matplotlib.pyplot as plt
 import cartopy.crs as ccrs
+import cartopy
+import seaborn as sns
+import numpy as np
+
 from .plot import _var2d
 from .utils_geo import apply_mask_axis
+from .cyclones import load_ibtracs
 
 from matplotlib.axes import Axes
 from cartopy.mpl.geoaxes import GeoAxes
+
 GeoAxes._pcolormesh_patched = Axes.pcolormesh
 
 # Ne peut pas fonctionner avec des subplots de la même façon que lon_lat_plot car on ne peut pas changer la projection d'un ax existant. Voire pour faire une fonction supplémentaire pour gérer ça ?
 # Actuellement, pour utiliser des subplots, les créer avec plt.subplots(a, b, subplot_kw = {'projection':ccrs.Robinson()})
 
 
-def lon_lat_plot_map(lon, lat, var, lon_axis=-1, lat_axis=-2, fig_ax=None, title='', cmap="bwr", \
-                     colorbar_label='', norm=None, smooth=False, projection=ccrs.Robinson(), \
-                     set_global=False, coastlines=True, grid=False, savefig = False, filename = 'saved_fig.png'):
+def lon_lat_plot_map(
+    lon,
+    lat,
+    var,
+    lon_axis=-1,
+    lat_axis=-2,
+    fig_ax=None,
+    title="",
+    cmap="bwr",
+    colorbar_label="",
+    norm=None,
+    smooth=False,
+    projection=ccrs.Robinson(),
+    set_global=False,
+    coastlines=True,
+    grid=False,
+    savefig=False,
+    filename="saved_fig.png",
+):
     """Plot a 2D map of the data with cartopy.
 
     Parameters
@@ -42,7 +63,9 @@ def lon_lat_plot_map(lon, lat, var, lon_axis=-1, lat_axis=-2, fig_ax=None, title
     colorbar_label : str, optional
         label to be shown beside the colorbar, by default ''
     norm : matplotlib.colors.<any>Norm, optional
-        normalization of the colormap, by default TwoSlopeNorm(vcenter=0)
+        normalization for the colormap, by default None
+        Example : with `import matplotlib.colors as c` in header of your script
+            * For centering diverging colormap : c.DivergingNorm(vcenter = 0.0)
     smooth : bool, optional
         if True, contourf is used instead of pcolormesh, by default False
     projection : cartopy.crs projection, optional
@@ -70,7 +93,8 @@ def lon_lat_plot_map(lon, lat, var, lon_axis=-1, lat_axis=-2, fig_ax=None, title
     mask = ~((lat > 88) | (lat < -88))
     var2D = apply_mask_axis(var2D, mask, axis=lat_axis)
     lat = lat[mask]
-    if any(mask == False) : print("Warning, some values too close to the pole(s) were not displayed.")
+    if any(mask == False):
+        print("Warning, some values too close to the pole(s) were not displayed.")
 
     # Plotting
     if fig_ax == None:
@@ -86,12 +110,24 @@ def lon_lat_plot_map(lon, lat, var, lon_axis=-1, lat_axis=-2, fig_ax=None, title
         ax.gridlines(crs=projection)
 
     if not smooth:
-        C = ax.pcolormesh(lon, lat, var2D, cmap=cmap,
-                          norm=norm, transform=ccrs.PlateCarree(), shading = "nearest")
+        C = ax.pcolormesh(
+            lon,
+            lat,
+            var2D,
+            cmap=cmap,
+            norm=norm,
+            transform=ccrs.PlateCarree(),
+            shading="nearest",
+        )
     else:
-        C = ax.contourf(lon, lat, var2D, cmap=cmap, norm=norm,
-                        transform=ccrs.PlateCarree())
-    fig.colorbar(C, ax=ax, label=colorbar_label,)
+        C = ax.contourf(
+            lon, lat, var2D, cmap=cmap, norm=norm, transform=ccrs.PlateCarree()
+        )
+    fig.colorbar(
+        C,
+        ax=ax,
+        label=colorbar_label,
+    )
     ax.set_ylabel("Latitude (°)")
     ax.set_xlabel("Longitude (°)")
     ax.set_title(title)
@@ -103,7 +139,21 @@ def lon_lat_plot_map(lon, lat, var, lon_axis=-1, lat_axis=-2, fig_ax=None, title
     return None
 
 
-def scatterplot_map(lons, lats, fig_ax=None, color='k', size=1, title='', projection=ccrs.Robinson(), set_global=False, coastlines=True, grid=False, link=False, linecolor='k', linewidth=1):
+def scatterplot_map(
+    lons,
+    lats,
+    fig_ax=None,
+    color="k",
+    size=1,
+    title="",
+    projection=ccrs.Robinson(),
+    set_global=False,
+    coastlines=True,
+    grid=False,
+    link=False,
+    linecolor="k",
+    linewidth=1,
+):
     """Plot points on a map.
 
     Parameters
@@ -153,22 +203,94 @@ def scatterplot_map(lons, lats, fig_ax=None, color='k', size=1, title='', projec
         ax.gridlines()
     ax.scatter(lons, lats, transform=ccrs.PlateCarree(), s=size, c=color)
     if link:
-        ax.plot(lons, lats, transform=ccrs.PlateCarree(),
-                c=linecolor, linewidth=linewidth)
+        ax.plot(
+            lons, lats, transform=ccrs.PlateCarree(), c=linecolor, linewidth=linewidth
+        )
 
     ax.set_title(title)
 
     return None
 
 
-zooms = {"NI": ccrs.NearsidePerspective(70, 20, 35785831/2),
-         "SI": ccrs.NearsidePerspective(70, -20, 35785831/2),
-         "AUS": ccrs.NearsidePerspective(135, -20, 35785831/2),
-         "WNP": ccrs.NearsidePerspective(150, 20, 35785831/2),
-         "SP": ccrs.NearsidePerspective(200, -20, 35785831/2),
-         "ENP": ccrs.NearsidePerspective(240, 20, 35785831/2),
-         "ATL": ccrs.NearsidePerspective(280, 20, 35785831/2)}
+def plot_tracks(
+    tracks,
+    lon_col="lon",
+    lat_col="lat",
+    id_col="track_id",
+    id=None,
+    projection=ccrs.Robinson(central_longitude=180.0),
+    intensity_col="wind",
+    fig_ax=None,
+    figsize=[10, 15],
+    cmap="RdYlGn_r",
+    draw_lines=True,
+):
+    """
+    Function to plot tracks from the tracks.txt file generated by TempestExtremes
+
+    Parameters
+    ----------
+    cmap
+    tracks: pandas DataFrame of tracks points
+    id_col: name of the column in track with cyclones id
+    id: id of the track(s) to plot
+    projection: ccrs projection to use for the plot
+    intensity_col: name of the column in tracks to use as color
+
+    Returns
+    -------
+    None. Produces a plot.
+    """
+
+    if type(id) == str:
+        id = [id]
+    if (type(id) == list) | (type(id) == np.ndarray):
+        tracks = tracks[tracks[id_col].isin(id)]
+
+    # Plotting
+    if fig_ax == None:
+        fig = plt.figure(figsize=figsize)
+        ax = plt.axes(projection=projection)
+        ax.coastlines()
+        ax.gridlines(draw_labels=True)
+        ax.add_feature(cartopy.feature.OCEAN, zorder=0, facecolor="azure")
+        ax.add_feature(cartopy.feature.LAND, zorder=0, edgecolor="black")
+    else:
+        fig, ax = fig_ax
+
+    if draw_lines:
+        for id in tracks[id_col].unique():
+            c = tracks[tracks[id_col] == id]
+            lon = c[lon_col].values
+            lat = c[lat_col].values
+            ax.plot(
+                lon, lat, transform=ccrs.PlateCarree(), c="k", alpha=0.7, linewidth=0.5
+            )
+
+    sns.scatterplot(
+        data=tracks,
+        x=lon_col,
+        y=lat_col,
+        hue=intensity_col,
+        ax=ax,
+        transform=ccrs.PlateCarree(),
+        palette=cmap,
+        size=intensity_col,
+        sizes=(4, 20),
+    )
+    return fig, ax
+
+
+zooms = {
+    "NI": ccrs.NearsidePerspective(70, 20, 35785831 / 2),
+    "SI": ccrs.NearsidePerspective(70, -20, 35785831 / 2),
+    "AUS": ccrs.NearsidePerspective(135, -20, 35785831 / 2),
+    "WNP": ccrs.NearsidePerspective(150, 20, 35785831 / 2),
+    "SP": ccrs.NearsidePerspective(200, -20, 35785831 / 2),
+    "ENP": ccrs.NearsidePerspective(240, 20, 35785831 / 2),
+    "ATL": ccrs.NearsidePerspective(280, 20, 35785831 / 2),
+}
 
 
 if __name__ == "__main__":
-    pass
+    plot_tracks()
